/**
 *
 */
package de.intevation.gnv.artifacts;

import java.io.FileOutputStream;

import org.apache.log4j.Logger;
import org.w3c.dom.Document;

import de.intevation.artifacts.Artifact;
import de.intevation.artifacts.ArtifactFactory;
import de.intevation.artifacts.CallContext;

/**
 * @author Tim Englich <tim.englich@intevation.de>
 *
 */
public class InstantaneousPointHorizontalProfileTestCase extends
                                                        GNVArtifactsTestCaseBase {

    private static Logger log = Logger.getLogger(InstantaneousPointHorizontalProfileTestCase.class);
    
    /**
     * Constructor
     */
    public InstantaneousPointHorizontalProfileTestCase() {
    }

    /**
     * Constructor
     * @param name
     */
    public InstantaneousPointHorizontalProfileTestCase(String name) {
        super(name);
    }

    /**
     * @see de.intevation.gnv.artifacts.GNVArtifactsTestCaseBase#testArtifact()
     */
    @Override
    public void testArtifact() {
        try {
            log.debug("GNVArtifactsTestCase." +
                      "testHorizontalProfileInstantaneousPointArtifact");
            String artefactName = "fis_delphin";
            ArtifactFactory artifactFactory = this
                    .getArtifactFactory(artefactName);
            assertNotNull(artifactFactory);
            log.debug("VerticalProfile-ArtifactFactory is available");
            Artifact artifact = artifactFactory.createArtifact(
                    "" + System.currentTimeMillis(), bootstrap.getContext());
            assertNotNull(artifact);
            log.debug("VerticalProfile-Artifact is available");

            CallContext cc = createCallContext();
            Document describeDocument = this.readDocument("src/test/ressources/horizontalProfile_instantaneouspoint/horizontalprofile_describe.xml");
            
            int steps = 9;
            
            for (int i = 0; i < steps; i++){
            
                this.doNextStep(
                            artifact,
                            cc,
                            "src/test/ressources/horizontalProfile_instantaneouspoint/" +
                            "horizontalprofile_step_0"+i+"_feed.xml",
                            "src/test/ressources/horizontalProfile_instantaneouspoint/" +
                            "horizontalprofile_step_0"+i+"_advance.xml", 
                            describeDocument);
            }

            Document outputData = artifact.describe(describeDocument, cc);
            FileOutputStream fos = null;
            FileOutputStream fos2 = null;
            FileOutputStream fos3 = null;
            FileOutputStream fos4 = null;
            try {
                fos = new FileOutputStream(
                        "src/test/results/horizontalprofile_instantaneouspoint"
                                + System.currentTimeMillis() + ".png");
                fos2 = new FileOutputStream(
                        "src/test/results/horizontalprofile_instantaneouspoint"
                                + System.currentTimeMillis() + ".xml");
                fos3 = new FileOutputStream(
                        "src/test/results/horizontalprofile_instantaneouspoint"
                                + System.currentTimeMillis() + ".csv");
                fos4 = new FileOutputStream(
                        "src/test/results/horizontalprofile_instantaneouspoint"
                                + System.currentTimeMillis() + ".odv");
                artifact.out(this.readDocument("src/test/ressources/" +
                                               "horizontalProfile_instantaneouspoint/" +
                                               "horizontalprofile_step_08_out_statistics.xml"),
                             fos2,cc);
                artifact.out(this.readDocument("src/test/ressources/" +
                                               "horizontalProfile_instantaneouspoint/" +
                                               "horizontalprofile_step_08_out_chart.xml"),
                             fos,cc);
                artifact.out(this.readDocument("src/test/ressources/" +
                                               "horizontalProfile_instantaneouspoint/" +
                                               "horizontalprofile_step_08_out_csv.xml"),
                             fos3,cc);
                artifact.out(this.readDocument("src/test/ressources/" +
                                               "horizontalProfile_instantaneouspoint/" +
                                               "horizontalprofile_step_08_out_odv.xml"),
                            fos4,cc);
            } catch (Exception e) {
                log.error(e, e);
                fail();
            } finally {
                try {
                    fos.flush();
                    fos.close();
                    fos2.flush();
                    fos2.close();
                    fos3.flush();
                    fos3.close();
                } catch (Exception e) {
                    log.error(e, e);
                }
            }
        } catch (Exception e) {
            log.error(e, e);
            fail();
        }
    }

}
